; 
; PETSCII Doctors
;
; Presented by Arkanix Labs in 2019
;
; A simple graphic collection displaying C64
; PETSCII images of all the Doctors from the
; BBC series Doctor Who.
;
; Code and music by aNdy/AL/Cosine
; Graphics by w0rm/AL (with support from aNdy)
; Thanks to Moloch/TRIAD for challenging me!
; Thanks to T.M.R/Cosine for all your patience!
;
; This source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; The final build was compressed and squished using
; Exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/
;
; Questions about this code or about how the binaries
; were created can be asked on the Arkanix Labs forum...
; www.arkanixlabs.com/forum
;

; Specify a file name and format for the assembled program

		!to "sourcebuild.prg",cbm

; Add a sprinkle of charset and music binaries!	

		* = $0900
music	!binary "data/music.prg",,2
	
		* = $2000
		!binary "data/charset.chr"
		
; Position of the raster interrupt(s)
; 'rp' is short for 'raster position'! Duh!

rp		= $00		; very first line of screen! More duh!

; Some label assignments (variables in BASIC speak)

sync	 = $51		; raster sync anim delay variable
vor_cnt  = $52		; vortex animation counter
not_cnt	 = $53		; note page colour wash counter
not_tim  = $54		; note page colour wash timer
wash	 = $55		; colour wash on or off variable
print    = $56		; print screen on or off variable
border   = $57		; variable holding border colour
backgrd	 = $58		; variable holding background colour

; Add a BASIC startline (SYS 16384) for auto-run

		* = $0801
		!word code_entry-2
		!byte $00,$00,$9e
		!text "16384"
		!byte $00,$00,$00

; Start point for the code

		* = $4000

; Stop interrupts, disable the ROMS and set up NMI and
; IRQ interrupt pointers		
				
code_entry

		sei			; disable maskable IRQs
		
		lda #$35	; kill EVERYTHING (MWHAHA!) except $f000-$ffff
		sta $01
		
; setup nmi

		lda #<nmi
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d ; disable timer interrupts which can be generated by the two CIA chips
		sta $dd0d ; the kernal uses such an interrupt to flash the cursor and scan the
				  ; keyboard, so we better stop it!

		lda $dc0d ; by reading these two registers we negate any pending CIA irqs.
		lda $dd0d ; if we don't do this, a pending CIA irq might occur after we
				  ; finish setting up our irq. we don't want that to happen.

		lda #$00  ; where raster starts on screen, usually at top but can be different
		sta $d012

		lda #$1b  ; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011 ; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019 ; clear interupt bit
		sta $d01a ; tell vicii to generate interupt

		lda #$35  ; turn off basic and kernal rom thus
		sta $01   ; c64 now sees RAM everywhere except at $d000-$e000
		
		lda #$18  ; custom font charset
		sta $d018

		cli
		
; Setup for the very first run...

		lda #$00					; load zero to accumalator

; Set the music driver		
		
		jsr music+$00				; set music driver ready
		
; make sure the text colour wash is off at the start		
		
		sta wash					; colour wash is off at start
									; with 0 from accumalator
				
		lda #$01					; 1 to accumalator
		sta border					; store 1 to border variable
		sta backgrd					; store 1 to background variable
		
; clear the screen by calling a subroutine further down the code

		jsr clear_screen

; now for the main loop that draws the screens in order
; starting with title screen, then waits for a space press each
; time by calling a subroutine called 'getin'. when the last
; page is reached (notes), the program loops back to 'main loop'.
				
main_loop

; print title screen

		jsr copy_title		; copy title screen data to print buffer store
		jsr print_screen	; print the screen
		jsr getin			; go to 'getin' subroutine for space press
		
; print doctors 1 & 2
		
		jsr vortex			; show the vortex animation
		jsr copy_doc12		; copy Doc 1&2 data to print bufferstore
		jsr print_screen	; print the screen		
		jsr getin			; go to 'getin' subroutine for space press
		
; print doctors 3 & 4
	
		jsr vortex			; show the vortex animation
		jsr copy_doc34		; copy doctors 3 and 4
		jsr print_screen	; print
		jsr getin			; gosub 'getin'
		
; print doctors 5 & 6
	
		jsr vortex			; etc, etc!!
		jsr copy_doc56		; and so on and so on!!!!
		jsr print_screen
		jsr getin
		
; print doctors 7 & 8
	
		jsr vortex
		jsr copy_doc78
		jsr print_screen
		jsr getin
		
; print doctors War & 9
	
		jsr vortex
		jsr copy_docw9
		jsr print_screen
		jsr getin							
		
; print doctors 10 & 11

		jsr vortex
		jsr copy_doc1011
		jsr print_screen
		jsr getin
		
; print doctors 12 & 13

		jsr vortex
		jsr copy_doc1213
		jsr print_screen
		jsr getin
		
; print the final notes page

		jsr vortex			; show the vortex anination
		
		lda #$00			; black needed for note page, so
		sta backgrd
		sta border
		
		jsr copy_notes		; copy notes page to print store
		jsr print_screen	; print the notes screen	
		
		lda #$01			; switch on the notes page
		sta wash			; colour wash

		jsr getin			; goto 'getin' subroutine for space press 
		
							; once space is pressed...
		lda #$00			; switch off the notes
		sta wash			; page colour wash	
		
		jsr vortex			; show the vortex animation
		
		jmp main_loop		; now start all over again by jumping
							; back to the 'main_loop' label above
							; and show the titles again
		
							
; Subroutines start here ===========================================

; various subroutines to get things printed, detect key presses
; or delay animation live below here. they are called from the
; main loop above!							
							
							
; Vortex animation subroutine ----------------------------------
									
; All the pages are drawn in the main loop above, so here's
; the subroutine that gets called to draw the vortex 'animation'

; the vortex animation loop does one loop of the animation,
; but when run you'll see 3 loops. this is controlled by the
; vortex counter that tells the animation to run until
; 3 loops have been completed
		
vortex
		lda #00
		sta vor_cnt			; vortex counter to 0
		sta backgrd

vortex_loop					; votex anim main loop	
		
		jsr copy_vortex1	; copy vortex anim 1 data to print store
		lda #$0B
		sta border			; grey 3 to border variable	
		jsr print_screen	; print the screen
		jsr anim_delay		; a little delay to slowwww the anim!

		jsr copy_vortex2	; copy vortex anim 2 data to print store
		lda #$04
		sta border			; purple to border variable
		jsr print_screen
		jsr anim_delay		; a little delay to slow the anim!
				
		jsr copy_vortex3	; etc, etc...
		lda #$0E
		sta border			; light blue to border variable
		jsr print_screen
		jsr anim_delay
		
		jsr copy_vortex4
		lda #$03
		sta border			; cyan		
		jsr print_screen
		jsr anim_delay
		
		jsr copy_vortex5
		lda #$01
		sta border			; white	
		jsr print_screen
		jsr anim_delay
							; thats 5 anim stages displayed
							; for 1 loop. now...
		lda vor_cnt			; load vortex counter
		inc vor_cnt			; increase the counter by 1
		cmp #$02			; have we done 3 loops?
		bne vortex_loop		; no? go back to vortex_loop above
		
							; yes, 3 loops done? ok then...
		
		jsr copy_vortex1	; draw tardis finish position at
		lda #$0B			; top because i'm fussy...
		sta border			; grey 3 to border variable	
		jsr print_screen
		jsr anim_delay		
			
		lda #$01			; white to both
		sta border			; border and
		sta backgrd			; background variables
		
		jsr clear_screen	; clear screen for next doctors
		
		rts					; go back to whichever part of the
							; main loop that called the vortex	
		

							
; Screen copy subroutines ----------------------------------														
		
; Each of these next subroutines copies the data from
; the tables of screen and colour data for each screen
; at the bottom of this code into the byte buffer store
; for the main print routine, ready for printing.

; These subroutines are called from the main loop at
; the top and at the end of the subroutine it returns (rts)
; back to the main loop at the top to whichever part
; called it.

	
			
; Copy the title screen into the print buffer store if
; this subroutine is called from above.
	
copy_title

		ldx #$00					; zero x register
copytitlescreen_loop				; begin loop
		lda scrramtitle,x			; load screen ram for title screen
		sta screen_store,x			; store to screen ram buffer
		lda colramtitle,x			; load colour ram for title screen
		sta colour_store,x			; store to colour ram buffer
		lda scrramtitle+250,x
		sta screen_store+250,x		; do this all the way down the screen
		lda colramtitle+250,x		; in 255 block chars to cover the
		sta colour_store+250,x		; the whole screen
		lda scrramtitle+500,x
		sta screen_store+500,x
		lda colramtitle+500,x
		sta colour_store+500,x		
		lda scrramtitle+750,x
		sta screen_store+750,x
		lda colramtitle+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa					; 255 reached?
		bne copytitlescreen_loop	; no? then loop back
									; yes?
		rts							; return to wherever this was called from
	
		
; Copy Doctors 1 and 2 screen into the print buffer store if 
; this subroutine is called from above...scrram12
				
copy_doc12

		ldx #$00
copydoc12screen_loop
		lda scrram12,x
		sta screen_store,x
		lda colram12,x
		sta colour_store,x		
		lda scrram12+250,x
		sta screen_store+250,x
		lda colram12+250,x
		sta colour_store+250,x		
		lda scrram12+500,x
		sta screen_store+500,x
		lda colram12+500,x
		sta colour_store+500,x		
		lda scrram12+750,x
		sta screen_store+750,x
		lda colram12+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc12screen_loop

		rts	


; Copy Doctors 3 and 4 into print buffer store...
				
copy_doc34

		ldx #$00
copydoc34screen_loop
		lda scrram34,x
		sta screen_store,x
		lda colram34,x
		sta colour_store,x		
		lda scrram34+250,x
		sta screen_store+250,x
		lda colram34+250,x
		sta colour_store+250,x		
		lda scrram34+500,x
		sta screen_store+500,x
		lda colram34+500,x
		sta colour_store+500,x		
		lda scrram34+750,x
		sta screen_store+750,x
		lda colram34+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc34screen_loop

		rts				
	
		
; Copy Doctors 5 and 6
				
copy_doc56

		ldx #$00
copydoc56screen_loop
		lda scrram56,x
		sta screen_store,x
		lda colram56,x
		sta colour_store,x		
		lda scrram56+250,x
		sta screen_store+250,x
		lda colram56+250,x
		sta colour_store+250,x		
		lda scrram56+500,x
		sta screen_store+500,x
		lda colram56+500,x
		sta colour_store+500,x		
		lda scrram56+750,x
		sta screen_store+750,x
		lda colram56+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc56screen_loop

		rts			

				
; Copy Doctors 7 and 8
				
copy_doc78

		ldx #$00
copydoc78screen_loop
		lda scrram78,x
		sta screen_store,x
		lda colram78,x
		sta colour_store,x		
		lda scrram78+250,x
		sta screen_store+250,x
		lda colram78+250,x
		sta colour_store+250,x		
		lda scrram78+500,x
		sta screen_store+500,x
		lda colram78+500,x
		sta colour_store+500,x		
		lda scrram78+750,x
		sta screen_store+750,x
		lda colram78+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc78screen_loop

		rts			

		
; Copy Doctors War and 9
				
copy_docw9

		ldx #$00
copydocw9screen_loop
		lda scrramw9,x
		sta screen_store,x
		lda colramw9,x
		sta colour_store,x		
		lda scrramw9+250,x
		sta screen_store+250,x
		lda colramw9+250,x
		sta colour_store+250,x		
		lda scrramw9+500,x
		sta screen_store+500,x
		lda colramw9+500,x
		sta colour_store+500,x		
		lda scrramw9+750,x
		sta screen_store+750,x
		lda colramw9+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydocw9screen_loop

		rts	
		
		
; Copy Doctors 10 and 11
				
copy_doc1011

		ldx #$00
copydoc1011screen_loop
		lda scrram1011,x
		sta screen_store,x
		lda colram1011,x
		sta colour_store,x		
		lda scrram1011+250,x
		sta screen_store+250,x
		lda colram1011+250,x
		sta colour_store+250,x		
		lda scrram1011+500,x
		sta screen_store+500,x
		lda colram1011+500,x
		sta colour_store+500,x		
		lda scrram1011+750,x
		sta screen_store+750,x
		lda colram1011+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc1011screen_loop

		rts	
		
		
; Copy Doctors 12 and 13
				
copy_doc1213

		ldx #$00
copydoc1213screen_loop
		lda scrram1213,x
		sta screen_store,x
		lda colram1213,x
		sta colour_store,x		
		lda scrram1213+250,x
		sta screen_store+250,x
		lda colram1213+250,x
		sta colour_store+250,x		
		lda scrram1213+500,x
		sta screen_store+500,x
		lda colram1213+500,x
		sta colour_store+500,x		
		lda scrram1213+750,x
		sta screen_store+750,x
		lda colram1213+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copydoc1213screen_loop

		rts			
	
; copy notes page into the print store
; this page has no colour RAM!
; this page has a colour wash effect handled in the
; interupt code towards the bottom instead
				
copy_notes
				
		ldx #$00
copynotesscreen_loop
		lda scrramnotes,x
		sta screen_store,x
		lda #$00				; put black into colour ram
		sta colour_store,x		; store in case of any
		lda scrramnotes+250,x	; leftovers from previous
		sta screen_store+250,x	; screens. being overly
		lda #$00				; cautious here!
		sta colour_store+250,x		
		lda scrramnotes+500,x
		sta screen_store+500,x
		lda #$00
		sta colour_store+500,x		
		lda scrramnotes+750,x
		sta screen_store+750,x
		lda #$00
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copynotesscreen_loop

		rts		
		
				
; Copy vortex screen animation 1 into print buffer store...
				
copy_vortex1

		ldx #$00
copyvortex1screen_loop
		lda scrramvortex1,x
		sta screen_store,x
		lda colramvortex1,x
		sta colour_store,x		
		lda scrramvortex1+250,x
		sta screen_store+250,x
		lda colramvortex1+250,x
		sta colour_store+250,x		
		lda scrramvortex1+500,x
		sta screen_store+500,x
		lda colramvortex1+500,x
		sta colour_store+500,x		
		lda scrramvortex1+750,x
		sta screen_store+750,x
		lda colramvortex1+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copyvortex1screen_loop

		rts	

		
; Copy vortex screen anim 2
				
copy_vortex2

		ldx #$00
copyvortex2screen_loop
		lda scrramvortex2,x
		sta screen_store,x
		lda colramvortex2,x
		sta colour_store,x		
		lda scrramvortex2+250,x
		sta screen_store+250,x
		lda colramvortex2+250,x
		sta colour_store+250,x		
		lda scrramvortex2+500,x
		sta screen_store+500,x
		lda colramvortex2+500,x
		sta colour_store+500,x		
		lda scrramvortex2+750,x
		sta screen_store+750,x
		lda colramvortex2+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copyvortex2screen_loop

		rts	
		
; Copy vortex screen 3
				
copy_vortex3

		ldx #$00
copyvortex3screen_loop
		lda scrramvortex3,x
		sta screen_store,x
		lda colramvortex3,x
		sta colour_store,x		
		lda scrramvortex3+250,x
		sta screen_store+250,x
		lda colramvortex3+250,x
		sta colour_store+250,x		
		lda scrramvortex3+500,x
		sta screen_store+500,x
		lda colramvortex3+500,x
		sta colour_store+500,x		
		lda scrramvortex3+750,x
		sta screen_store+750,x
		lda colramvortex3+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copyvortex3screen_loop

		rts				
		

; Copy vortex screen 4
				
copy_vortex4

		ldx #$00
copyvortex4screen_loop
		lda scrramvortex4,x
		sta screen_store,x
		lda colramvortex4,x
		sta colour_store,x		
		lda scrramvortex4+250,x
		sta screen_store+250,x
		lda colramvortex4+250,x
		sta colour_store+250,x		
		lda scrramvortex4+500,x
		sta screen_store+500,x
		lda colramvortex4+500,x
		sta colour_store+500,x		
		lda scrramvortex4+750,x
		sta screen_store+750,x
		lda colramvortex4+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copyvortex4screen_loop

		rts							
		
		
; Copy vortex screen 5
				
copy_vortex5

		ldx #$00
copyvortex5screen_loop
		lda scrramvortex5,x
		sta screen_store,x
		lda colramvortex5,x
		sta colour_store,x		
		lda scrramvortex5+250,x
		sta screen_store+250,x
		lda colramvortex5+250,x
		sta colour_store+250,x		
		lda scrramvortex5+500,x
		sta screen_store+500,x
		lda colramvortex5+500,x
		sta colour_store+500,x		
		lda scrramvortex5+750,x
		sta screen_store+750,x
		lda colramvortex5+750,x
		sta colour_store+750,x					
		inx
		cpx #$fa
		bne copyvortex5screen_loop

		rts	
	
		
; Print screen subroutine ---------------------------------

; if this subroutine is called, it switches on the printing
; by storing 01 into the variable 'print'.  the actual
; prining is done in the interupt code towards the bottom
; of this code.  the printing is done on interupt to
; hopefully make sure everything is synced and no
; flicker occurs!  fingers crossed... :D

print_screen

		lda #$01
		sta print
		
		rts	

; Detect 'space' press subroutine, with key debounce----------------		

; detects spacebar keypress (get input - getin - geddit?)

getin
		lda $dc01			; CIA 1 Port B, controls some keyboard keys
		cmp #$ef			; is space pressed?
		bne getin			; no? loop back to 'getin'
		
							; yes? then debounce the keyboard
							; or the screens will flick
							; through without stopping!
							; carry on to key debounce below!
 	
; Key debounce to check space bar is released after press!

key_debounce
		lda $dc01			; is there a keypress still?
		cmp #$ff			; an idiot is still pressing something???
		bne key_debounce	; lock them in a loop till they stop!!
		
							; they've finally let the key go? then return (rts)
		rts					; to whichever part of the main loop at the top
							; called the space press subroutine

		
; Clear screen subroutine ----------------------------------		

clear_screen

        lda backgrd		; load whatever is in backgrnd variable
		sta $d021		; store to background! change colour!
		lda border		; load whatever is in border variable
		sta $d020		; store to border! change colour!

		ldx #$00		; zero x register		
		lda #$20		; value for 'empty space' in accum
clsloop
		sta $0400,x
		sta $0500,x
		sta $0600,x
		sta $0700,x
		inx
		bne clsloop
		
	   	rts				; return to where this was called from
	
		
; Animation delay subroutine -------------------------------

; Slows the animation and links to the
; raster interupt code

anim_delay

		ldx #$02		; change this to alter anim speed!
delay_loop
		jsr sync_wait
		dex
		bne delay_loop
		rts

sync_wait				; wait for sync update in irq code
		lda #$00
		sta sync
sw_loop
		cmp sync
		beq sw_loop

		rts

		
; End Subroutines =====================================


						
							
; IRQ interrupt code =================================

; Initiate an interupt!

int
		pha  
		txa
		pha
		tya
		pha
		
		lda $d019
		and #$01
		sta $d019
		
; Play the music
		
		jsr music+$03			; call music player
		jsr music+$03			; called twice because X2 speeed tune
		
; Print the screen!

; this routine will only run if it has been switched on
; in the mainline code above in the subroutine 'print_screen'
; if it has been switched on with 01 in the variable 'print'
; then this routine will print whatever data has been
; copied to and stored in the print buffer byte store
; using the copy data subroutines above in the mainline code

; note, both screen and colour RAM are made up of 1000
; bytes, so each copy and store below is done in 4 blocks
; of 250 bytes.


		lda print				; has the print routine been switched
		cmp #$01				; on by the mainline routine?
		bne wash_check			; no? go down to 'wash_check'
						
		lda border				; yes? load the border colour from the
		sta $d020				; vortex routine and shunt into border
		lda backgrd				; same for background
		sta $d021
			
		ldx #$00				; zero x register
printscreen_loop				; load up whatver is in the screen
		lda screen_store,x		; store buffer and write to the
		sta $0400,x				; screen ram
		lda screen_store+250,x
		sta $0400+250,x
		lda screen_store+500,x
		sta $0400+500,x
		lda screen_store+750,x
		sta $0400+750,x	
		inx
		cpx #$fa
		bne printscreen_loop	; all written? no? loop back!
								; yes? then...
		ldx #$00				; zero x register
printscreen_loop2				; load whatever is in the colour
		lda colour_store,x		; store buffer and write to the
		sta $d800,x				; colour ram
		lda colour_store+250,x
		sta $d800+250,x	
		lda colour_store+500,x
		sta $d800+500,x	
		lda colour_store+750,x
		sta $d800+750,x	
		inx
		cpx #$fa
		bne printscreen_loop2	; all written? no? loop back!
								; yes? then...
		lda #$00				; switch off the print routine
		sta print				; because the printing should be done!

		
; Colour wash effect for notes page		

wash_check		

		lda wash			; load wash variable
		cmp #$01			; is it switched on?
		bne skip_wash		; no? then jump to 'skip_wash' below
							; otherwise yes? then execute colour wash
							; on next line below!	
		ldx #$00
col_upd						; colour wash loop
		lda wash_col_off,x
		clc
		adc not_cnt
		and #$0f
		tay
		lda wash_pulse,y	; load next colour from wash table
		
		sta $d800,x			; store to the different colour
		sta $d800+40,x		; ram locations down the screen
		sta $d800+80,x
		sta $d800+120,x
		sta $d800+160,x
		sta $d800+200,x
		sta $d800+240,x
		sta $d800+280,x
		sta $d800+320,x
		sta $d800+360,x
		sta $d800+400,x
		sta $d800+440,x
		sta $d9e0,x
		sta $d9e0+40,x
		sta $d9e0+80,x
		sta $d9e0+120,x
		sta $d9e0+160,x
		sta $d9e0+200,x
		sta $d9e0+240,x
		sta $d9e0+280,x
		sta $d9e0+320,x
		sta $d9e0+360,x
		sta $d9e0+400,x
		sta $d9e0+440,x
		sta $d9e0+480,x				

		inx
		cpx #$28
		bne col_upd

		ldx not_tim			; colour wash timer
		inx
		cpx #$03
		bcc tic_xb
		inc not_cnt
		ldx #$00
tic_xb	
		stx not_tim
		
		
skip_wash		
		
; Set sync variable for the	animation delay sub routine
		
		lda #$01			
		sta sync
			
; Exit the interupt
				
		pla
		tay
		pla
		tax
		pla
nmi		rti

; End IRQ interrupt code ====================================



; Data tables live here! =========================================

; each screen has 2 blocks of data (unoptimised)

; block 1 - screen RAM for each screen
; block 2 - colour RAM for each screen

; these screens were created in and exported by my cross-dev
; screen editor called 'ChillED'. This will be available to
; download from the Arkanix Labs forum soon...

;Screen data for title / intro screen
scrramtitle
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$FE,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$49,$0E,$20,$20,$32,$30,$31,$39,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$FE,$A0,$A0,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$3E,$41,$12,$0B,$01,$0E,$09,$18,$20,$4C,$01,$02,$13,$3C,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$10,$12,$05,$13,$05,$0E,$14,$13,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$F9,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$22,$50,$45,$54,$53,$43,$49,$49,$20,$20,$44,$0F,$03,$14,$0F,$12,$13,$22
!byte $20,$20,$20,$20,$20,$20,$20,$20,$EF,$7E,$20,$7C,$EF,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$6C,$FE,$A0,$FC,$20,$7C,$A0,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$03,$0F,$04,$09,$0E,$07,$20,$01,$4E,$04,$19,$20,$20
!byte $20,$20,$20,$6C,$FE,$A0,$A0,$A0,$A0,$FC,$20,$A0,$A0,$A0,$20,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$07,$12,$01,$10,$08,$09,$03,$13,$20,$17,$30,$12,$0D,$20,$20
!byte $20,$6C,$FE,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$0D,$15,$13,$09,$03,$20,$01,$4E,$04,$19,$20,$20
!byte $FE,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$FC,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$EC,$20,$20,$3E,$20,$50,$0C,$05,$01,$13,$05,$20,$15,$13,$05,$20,$01,$0E,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$EC,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$38,$35,$38,$30,$20,$53,$49,$44,$2E,$20,$20,$20,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$3E,$20,$53,$10,$05,$03,$09,$01,$0C,$20,$14,$08,$01,$0E,$0B,$13,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$14,$0F,$20,$4D,$0F,$0C,$0F,$03,$08,$20,$06,$0F,$12,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$08,$09,$13,$20,$08,$05,$0C,$10,$20,$01,$0E,$04,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$13,$15,$10,$10,$0F,$12,$14,$2E,$20,$20,$20,$20,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$3E,$20,$44,$05,$04,$09,$03,$01,$14,$05,$04,$20,$14,$0F,$20,$20,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$20,$A0,$A0,$20,$20,$20,$20,$20,$54,$2E,$4D,$2E,$52,$20,$20,$20,$54,$08,$01,$0E,$0B,$13,$20
!byte $20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$FE,$A0,$A0,$7B,$20,$20,$20,$20,$06,$0F,$12,$20,$01,$0C,$0C,$20,$19,$0F,$15,$12,$20,$20,$20
!byte $FE,$A0,$A0,$A0,$A0,$FC,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$FE,$A0,$A0,$A0,$A0,$A0,$FC,$20,$20,$20,$20,$10,$01,$14,$09,$05,$0E,$03,$05,$21,$20,$20,$20,$20,$20,$20
!byte $FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$7C,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$7E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$64,$64,$64,$64,$64,$20,$20,$20,$20
!byte $20,$20,$20,$7C,$FB,$A0,$A0,$A0,$A0,$EC,$20,$FB,$A0,$A0,$A0,$A0,$EC,$7E,$20,$20,$20,$20,$20,$3E,$20,$50,$12,$05,$13,$13,$20,$D3,$D0,$C1,$C3,$C5,$20,$14,$0F,$20
!byte $20,$20,$20,$20,$20,$7C,$FB,$A0,$EC,$20,$20,$20,$FB,$A0,$EC,$7E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$03,$08,$01,$0E,$07,$05,$20,$10,$01,$07,$05,$13,$21,$20,$20
		
colramtitle
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$0E,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$04,$04,$06,$00,$04,$04,$04,$04,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$0E,$06,$06,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$00,$0E,$0E,$0E,$0E,$04,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0E,$06,$06,$06,$06,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$04,$04,$04,$04,$04,$04,$04,$04,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0E,$06,$06,$06,$06,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$00,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E
!byte $00,$00,$00,$00,$00,$00,$00,$0E,$06,$0E,$0E,$0E,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0E,$0E,$0E,$06,$0E,$00,$0E,$0E,$06,$06,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$03,$0E,$0E,$0E,$0E,$00,$00
!byte $00,$00,$0E,$0E,$0E,$06,$06,$06,$06,$0E,$00,$06,$06,$06,$02,$06,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$06,$03,$0E,$0E,$0E,$0E,$00,$00
!byte $0E,$0E,$0E,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$0E,$0E,$00,$00,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$03,$0E,$0E,$0E,$0E,$00,$00
!byte $06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$00,$00,$00,$00,$00,$00,$00,$00
!byte $0E,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$0E,$00,$00,$04,$04,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$00,$06,$06,$00,$00
!byte $00,$06,$06,$06,$06,$0E,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$00,$00,$0E,$0E,$0E,$0E,$00,$06,$06,$06,$06,$00,$00,$00,$00,$00,$00
!byte $00,$06,$06,$06,$06,$0E,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$04,$04,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$06,$06,$06,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$06,$00,$00,$00,$00,$06,$06,$00,$0E,$0E,$0E,$0E,$0E,$0E,$00,$06,$06,$06,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$06,$00,$00,$00,$00,$06,$06,$06,$00,$06,$06,$06,$06,$00,$06,$06,$06,$00,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$06,$00,$00,$00,$00,$00,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$02,$06,$06,$00,$00,$00,$04,$04,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$00,$00,$00
!byte $00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$02,$06,$06,$0E,$06,$06,$00,$00,$00,$00,$00,$0E,$0E,$0E,$0E,$0E,$06,$00,$00,$06,$06,$06,$06,$06,$06,$00
!byte $00,$06,$06,$06,$06,$0E,$06,$06,$06,$06,$00,$06,$06,$06,$0E,$06,$06,$0E,$06,$06,$0E,$00,$00,$00,$00,$06,$06,$06,$00,$06,$06,$06,$00,$06,$06,$06,$06,$00,$00,$00
!byte $0E,$06,$06,$06,$06,$0E,$06,$06,$06,$06,$00,$06,$06,$06,$0E,$06,$06,$06,$06,$06,$0E,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$00,$00,$00,$00
!byte $06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$0E,$0E,$06,$06,$06,$06,$06,$06,$06,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$0E,$00,$00,$00,$00,$00,$00,$06,$00,$00,$00,$00,$0E,$0E,$0E,$0E,$0E,$00,$00,$00,$00
!byte $00,$00,$00,$0E,$0E,$06,$06,$06,$06,$0E,$00,$0E,$06,$06,$06,$06,$0E,$0E,$00,$00,$00,$00,$00,$04,$04,$06,$06,$06,$06,$06,$0E,$0E,$0E,$0E,$0E,$0E,$00,$06,$06,$00
!byte $00,$00,$00,$00,$00,$0E,$0E,$06,$0E,$00,$00,$06,$0E,$06,$0E,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00


;Screen data for doctors 1 and 2
scrram12
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$20,$20,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$31,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$57,$09,$0C,$0C,$09,$01,$0D,$20,$48,$01,$12,$14,$0E,$05,$0C,$0C,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$32,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$31,$39,$36,$33,$2D,$31,$39,$36,$36,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$50,$01,$14,$12,$09,$03,$0B,$20,$54,$12,$0F,$15,$07,$08,$14,$0F,$0E,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$31,$39,$36,$36,$2D,$31,$39,$36,$39,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram12
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0F,$00,$0F,$0F,$0F,$0F,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0A,$00,$0F,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0B,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$00,$00,$0A,$0F,$0A,$0F,$0A,$01,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$01,$08,$0A,$0A,$0A,$0A,$0A,$08,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$08,$00,$08,$00,$00,$0B,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$01,$0A,$0A,$0A,$00,$0A,$0A,$0A,$01,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$0B,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$0B,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0B,$0C,$00,$08,$0A,$0A,$0A,$08,$00,$0C,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0C,$0B,$00,$0B,$0C,$06,$06,$06,$0C,$0B,$00,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$08,$0A,$0A,$0A,$08,$00,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$0B,$0B,$0F,$00,$0F,$0B,$0B,$00,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$0B,$0F,$00,$0F,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0C,$05,$05,$05,$0C,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$08,$0B,$0F,$0B,$08,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$00,$0B,$0F,$00,$0F,$0B,$00,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$08,$00,$00,$00,$08,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0F,$00,$0F,$0B,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$08,$00,$00,$00,$08,$08,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$09,$09,$09,$08,$09,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$09,$09,$00,$00,$00,$09,$09,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$08,$00,$00,$00,$08,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$00,$00,$09,$08,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$09,$00,$00,$00,$09,$09,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00


;Screen data for doctors 3 and 4
scrram34
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$33,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$4A,$0F,$0E,$20,$50,$05,$12,$14,$17,$05,$05,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$34,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$31,$39,$37,$30,$2D,$31,$39,$37,$34,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$54,$0F,$0D,$20,$42,$01,$0B,$05,$12,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$31,$39,$37,$34,$2D,$31,$39,$38,$31,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram34
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0B,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0B,$0B,$0C,$0F,$0F,$0F,$0C,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$08,$00,$09,$00,$08,$0F,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0B,$00,$0C,$0F,$0F,$0F,$0F,$0F,$0C,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$00,$08,$09,$09,$00,$08,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0B,$0C,$0F,$0F,$0F,$0F,$0A,$0F,$0F,$0C,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$08,$08,$00,$08,$09,$08,$09,$09,$00,$08,$08,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0F,$0F,$0A,$0A,$0A,$0A,$0A,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$08,$09,$08,$09,$09,$00,$09,$09,$08,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$01,$0A,$00,$0A,$0A,$0A,$00,$0A,$01,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$08,$0A,$08,$0A,$08,$0A,$08,$00,$0B,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$0B,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$0B,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0C,$00,$0C,$00,$0A,$0A,$0A,$0A,$0A,$00,$0C,$00,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$0F,$00,$0B,$02,$0C,$00,$00,$00,$00,$00,$0C,$02,$0B,$00,$0F,$00,$00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$01,$00,$0B,$02,$0C,$05,$02,$05,$0C,$02,$0B,$00,$01,$00,$00,$00,$00,$00,$00,$00,$09,$07,$00,$0A,$0A,$0A,$0A,$0A,$00,$06,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$01,$00,$0B,$02,$0B,$00,$0B,$02,$0B,$00,$01,$0A,$00,$00,$00,$00,$00,$00,$09,$09,$09,$02,$00,$00,$00,$00,$00,$07,$09,$09,$09,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$02,$0B,$0B,$0B,$02,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$09,$06,$0D,$08,$04,$05,$09,$00,$09,$08,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$0B,$02,$0B,$0B,$0B,$02,$0B,$00,$02,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$08,$03,$04,$03,$07,$0F,$08,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$00,$0B,$00,$00,$00,$0B,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0D,$05,$08,$08,$04,$09,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$0E,$09,$09,$05,$0E,$09,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$0B,$00,$00,$00,$00,$00,$0B,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$04,$00,$00,$02,$07,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0D,$00,$00,$03,$04,$09,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$00,$00,$06,$05,$09,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$0A
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00


;Screen data for doctors 5 and 6
scrram56
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$3F,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$3F,$A0,$A0,$A0,$3F,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$35,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$50,$05,$14,$05,$12,$20,$44,$01,$16,$09,$04,$13,$0F,$0E,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$36,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$31,$39,$38,$32,$2D,$31,$39,$38,$34,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$43,$0F,$0C,$09,$0E,$20,$42,$01,$0B,$05,$12,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$31,$39,$38,$34,$2D,$31,$39,$38,$36,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram56
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$00,$00,$09,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$08,$00,$07,$07,$07,$07,$07,$00,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$08,$00,$08,$00,$09,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0A,$09,$07,$07,$07,$07,$07,$07,$07,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$07,$09,$07,$09,$07,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$08,$00,$07,$0A,$07,$0A,$07,$07,$07,$00,$08,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$07,$07,$07,$07,$07,$07,$07,$09,$08,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$07,$08,$0A,$0A,$0A,$0A,$0A,$08,$07,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$07,$07,$07,$07,$07,$07,$07,$08,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$07,$07,$0A,$07,$0A,$07,$0A,$07,$07,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$07,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$09,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$08,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$07,$00,$08,$0A,$0A,$0A,$08,$05,$07,$00,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$07,$07,$02,$00,$00,$00,$00,$05,$05,$05,$07,$00,$08,$00,$00,$00,$00,$00,$0F,$02,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$02,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$07,$0B,$01,$02,$01,$01,$01,$02,$0D,$0B,$07,$0F,$00,$00,$00,$00,$00,$00,$02,$00,$06,$00,$08,$0A,$0A,$0A,$08,$00,$06,$00,$02,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$0F,$0B,$02,$02,$02,$0B,$0D,$00,$0A,$0A,$00,$00,$00,$00,$00,$08,$00,$02,$0E,$06,$00,$00,$00,$00,$00,$06,$0E,$02,$00,$08,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$02,$01,$01,$01,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$0F,$02,$07,$0A,$03,$03,$03,$0A,$0A,$02,$0F,$07,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$02,$07,$02,$02,$02,$07,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$07,$02,$01,$03,$01,$02,$0A,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$07,$08,$00,$00,$00,$08,$07,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$02,$0F,$01,$0F,$02,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$02,$07,$00,$00,$00,$07,$02,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$08,$02,$02,$02,$08,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$02,$00,$00,$00,$02,$08,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$00,$00,$09,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$08,$00,$00,$00,$08,$0A,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$00,$00,$09,$08,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;Screen data for doctors 7 and 8
scrram78
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$E4,$3F,$A0,$3F,$E4,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$3F,$3F,$3F,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$37,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$53,$19,$0C,$16,$05,$13,$14,$05,$12,$20,$4D,$03,$43,$0F,$19,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$38,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$31,$39,$38,$37,$2D,$31,$39,$38,$39,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$50,$01,$15,$0C,$20,$4D,$03,$47,$01,$0E,$0E,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$31,$39,$39,$36,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram78
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0C,$0F,$0F,$0F,$0F,$0F,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$00,$02,$02,$02,$02,$02,$02,$02,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$09,$00,$09,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0C,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$09,$08,$09,$08,$09,$08,$09,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$00,$08,$0A,$08,$0A,$08,$0A,$08,$00,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$08,$09,$08,$08,$08,$09,$08,$00,$09,$09,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$09,$08,$08,$08,$0A,$08,$0A,$08,$08,$08,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0B,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$0A,$0A,$0A,$0A,$0A,$08,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$08,$0A,$00,$0A,$0A,$0A,$00,$0A,$08,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0C,$00,$0A,$0A,$0A,$0A,$0A,$00,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$0A,$0A,$0A,$00,$0A,$0A,$0A,$08,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$0F,$0F,$00,$00,$00,$00,$00,$0F,$0F,$0C,$00,$00,$00,$00,$00,$00,$00,$0F,$09,$00,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$00,$09,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0C,$0F,$0F,$0F,$02,$03,$08,$03,$02,$0F,$0F,$0F,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0A,$0A,$0A,$0A,$0A,$00,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$0F,$02,$02,$03,$02,$02,$0F,$00,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$05,$05,$0B,$00,$00,$00,$00,$00,$0B,$05,$05,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0F,$02,$02,$02,$02,$02,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$05,$05,$05,$01,$09,$09,$09,$01,$05,$05,$05,$0B,$00,$00,$00,$00
!byte $00,$00,$00,$00,$02,$02,$00,$0C,$08,$08,$08,$08,$08,$0C,$00,$02,$02,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$05,$0B,$01,$09,$01,$0B,$05,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$08,$08,$00,$00,$00,$08,$08,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$05,$05,$08,$08,$08,$05,$05,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$00,$08,$09,$00,$00,$00,$09,$08,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$05,$05,$0B,$08,$0B,$05,$05,$00,$02,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$00,$09,$09,$00,$00,$00,$09,$09,$00,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$05,$09,$00,$00,$00,$09,$05,$00,$02,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$0B,$09,$00,$00,$00,$09,$0B,$00,$02,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$09,$09,$00,$00,$00,$09,$09,$00,$02,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;Screen data for doctors War and 9
scrramw9
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$F8,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$F8,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$57,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$4A,$0F,$08,$0E,$20,$48,$15,$12,$14,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$39,$20,$20,$20,$20
!byte $20,$20,$20,$20,$54,$08,$05,$20,$57,$01,$12,$20,$44,$0F,$03,$14,$0F,$12,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$43,$08,$12,$09,$13,$14,$0F,$10,$08,$05,$12,$20,$45,$03,$03,$0C,$05,$13,$14,$0F,$0E
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$32,$30,$30,$35,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colramw9
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0F,$0B,$0F,$0B,$0F,$0B,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0F,$00,$0F,$0F,$0F,$0F,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$08,$00,$08,$00,$09,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0B,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0B,$00,$0B,$00,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$00,$0F,$0F,$0A,$0F,$0A,$0F,$0F,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0F,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$0A,$00,$00,$00,$0A,$00,$00,$0B,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0B,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$0B,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$0B,$00,$08,$0C,$0F,$0F,$0F,$0C,$08,$00,$0B,$0F,$00,$00,$00,$00,$00,$00,$00,$0B,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$0B,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0C,$00,$09,$00,$0B,$0F,$0F,$0F,$0B,$00,$09,$00,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$0F,$00,$09,$09,$09,$00,$00,$0C,$00,$00,$09,$09,$09,$00,$0F,$00,$00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$09,$09,$0B,$09,$02,$02,$02,$02,$02,$09,$0B,$09,$09,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$00,$0A,$0A,$0A,$0A,$0A,$00,$0B,$0B,$0C,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$09,$0B,$02,$0B,$02,$0B,$09,$00,$0A,$0A,$00,$00,$00,$00,$00,$0F,$0B,$00,$00,$00,$0B,$08,$08,$08,$0B,$00,$00,$00,$0B,$0F,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$09,$0B,$0B,$0B,$02,$0B,$09,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$0B,$05,$05,$05,$0B,$00,$00,$00,$00,$0B,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$09,$08,$0B,$0B,$0B,$08,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$00,$00,$05,$05,$05,$00,$00,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$09,$08,$00,$00,$00,$08,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$05,$05,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$09,$08,$00,$00,$00,$08,$09,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0B,$0B,$0B,$0B,$0B,$00,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$08,$00,$00,$00,$08,$0B,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;Screen data for doctors 10 and 11
scrram1011
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$BA,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$F4,$F4,$E4,$E7,$EA,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$BA,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$F4,$A0,$3A,$A0,$EA,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$F4,$A0,$3A,$A0,$EA,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$F4,$A0,$3A,$A0,$EA,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$31,$30,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$44,$01,$16,$09,$04,$20,$54,$05,$0E,$0E,$01,$0E,$14,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$31,$31,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$32,$30,$30,$35,$2D,$32,$30,$31,$30,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$4D,$01,$14,$14,$20,$20,$53,$0D,$09,$14,$08,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$32,$30,$31,$30,$2D,$32,$30,$31,$33,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram1011
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$09,$00,$09,$00,$09,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$08,$00,$08,$09,$09,$09,$08,$00,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$00,$08,$00,$08,$00,$09,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0A,$09,$08,$09,$09,$09,$09,$09,$08,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$09,$09,$09,$09,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$08,$00,$09,$09,$0A,$09,$08,$09,$09,$00,$08,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$09,$09,$08,$09,$09,$08,$09,$09,$08,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$09,$08,$0A,$0A,$0A,$0A,$0A,$08,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$09,$09,$09,$08,$0A,$08,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$08,$0A,$0A,$00,$0A,$0A,$0A,$00,$0A,$0A,$08,$00,$00,$00,$00,$00,$00,$00,$00,$08,$09,$09,$08,$09,$08,$0A,$0A,$08,$09,$08,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$0A,$0A,$0A,$0A,$0A,$08,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$09,$08,$0A,$00,$0A,$0A,$0A,$00,$0A,$08,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$08,$00,$0A,$0A,$0A,$0A,$0A,$00,$09,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$0A,$00,$0A,$0A,$0A,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$09,$08,$09,$00,$00,$00,$00,$00,$09,$08,$09,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$00,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$09,$08,$08,$08,$01,$02,$02,$02,$01,$08,$08,$08,$09,$00,$00,$00,$00,$00,$00,$00,$00,$08,$00,$0A,$0A,$0A,$0A,$0A,$00,$09,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$08,$06,$01,$02,$01,$06,$08,$00,$0A,$0A,$00,$00,$00,$00,$00,$00,$00,$09,$08,$09,$00,$00,$00,$00,$00,$09,$08,$09,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$0B,$06,$06,$06,$0B,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$08,$08,$08,$02,$02,$02,$02,$02,$08,$08,$08,$09,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$06,$06,$06,$06,$06,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$08,$02,$01,$0F,$01,$02,$08,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$0B,$00,$00,$00,$0B,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$02,$01,$0F,$01,$02,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$08,$06,$00,$00,$00,$06,$08,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$08,$02,$01,$0F,$01,$02,$08,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0F,$0F,$00,$00,$00,$0F,$0F,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$0B,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;Screen data for doctors 12 and 13
scrram1213
!byte $20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$20,$A0,$A0,$A0,$20,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$AE,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$3A,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20
!byte $20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$3A,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$3A,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$E4,$E4,$E4,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$31,$32,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$50,$05,$14,$05,$12,$20,$43,$01,$10,$01,$0C,$04,$09,$20,$20,$20,$20,$20,$20,$20,$A0,$A0,$A0,$A0,$A0,$20,$A0,$A0,$A0,$A0,$A0,$31,$33,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$32,$30,$31,$34,$2D,$32,$30,$31,$37,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$4A,$0F,$04,$09,$05,$20,$57,$08,$09,$14,$14,$01,$0B,$05,$12,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$32,$30,$31,$38,$2D,$3F,$3F,$3F,$3F,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

colram1213
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$0B,$0C,$0B,$0C,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0B,$0F,$0C,$0F,$0C,$0F,$0C,$0F,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$0B,$0C,$0F,$0F,$0F,$0F,$0F,$0C,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$0F,$0F,$0F,$0F,$0F,$01,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0B,$0C,$0F,$0F,$0C,$0F,$0A,$0F,$0F,$0C,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$0F,$0F,$07,$07,$07,$0F,$0F,$07,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$0F,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$0F,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$01,$0F,$07,$07,$07,$07,$07,$07,$07,$0F,$01,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0A,$0A,$0A,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$0F,$07,$0F,$07,$0F,$07,$0F,$07,$0F,$07,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$07,$07,$07,$0F,$0A,$0F,$0A,$07,$07,$0F,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$0A,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$07,$07,$0F,$0A,$0A,$0A,$0A,$0A,$0F,$07,$07,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$0F,$00,$08,$0A,$0A,$0A,$0A,$0A,$08,$00,$0F,$0F,$00,$00,$00,$00,$00,$00,$07,$0F,$0F,$0A,$00,$0A,$0A,$0A,$00,$0A,$0F,$0F,$07,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$00,$0B,$00,$08,$0A,$0A,$0A,$08,$00,$0B,$00,$0F,$00,$00,$00,$00,$00,$00,$07,$07,$0A,$0A,$0A,$0A,$00,$0A,$0A,$0A,$0A,$07,$07,$00,$00,$00,$00
!byte $00,$00,$00,$0F,$00,$0B,$0B,$0B,$00,$00,$00,$00,$00,$0B,$0B,$0B,$00,$0F,$00,$00,$00,$00,$00,$07,$0F,$09,$0A,$0A,$0A,$0A,$0A,$0A,$0A,$09,$0F,$07,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0B,$0B,$00,$0B,$0B,$01,$0B,$01,$0B,$0B,$00,$0B,$0B,$00,$00,$00,$00,$00,$00,$0F,$00,$0F,$08,$0A,$0A,$0A,$0A,$0A,$08,$0F,$00,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0A,$0A,$00,$0B,$0B,$01,$0B,$01,$0B,$0B,$00,$0A,$0A,$00,$00,$00,$00,$00,$0F,$0B,$0F,$0C,$0C,$02,$0A,$0A,$0A,$02,$0C,$0C,$0F,$0B,$0F,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$0B,$0F,$0B,$0F,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0C,$0C,$0C,$07,$0B,$0B,$0B,$07,$0C,$0C,$0C,$0F,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$02,$0C,$0C,$0C,$02,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0A,$0A,$00,$0C,$07,$02,$02,$02,$07,$0C,$00,$0A,$0A,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$02,$02,$00,$00,$00,$02,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$07,$05,$05,$05,$07,$0C,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$02,$0B,$00,$00,$00,$0B,$02,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$07,$0B,$0B,$0B,$07,$0C,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$0B,$0B,$00,$00,$00,$0B,$0B,$00,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$06,$00,$00,$00,$06,$0C,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$00,$00,$00,$06,$06,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$09,$09,$00,$00,$00,$09,$09,$00,$0A,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00


; Screen data for notes page
; There is no colour data for this page
; because it has a colour wash effect
; that is handled in the interupt code!

scrramnotes
!byte $20,$22,$54,$08,$05,$12,$05,$27,$13,$20,$0E,$0F,$20,$10,$0F,$09,$0E,$14,$20,$02,$05,$09,$0E,$07,$20,$07,$12,$0F,$17,$0E,$20,$15,$10,$20,$09,$06,$20,$19,$0F,$15
!byte $03,$01,$0E,$27,$14,$20,$02,$05,$20,$03,$08,$09,$0C,$04,$09,$13,$08,$20,$13,$0F,$0D,$05,$14,$09,$0D,$05,$13,$2E,$22,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$46,$0F,$15,$12,$14,$08,$20,$44,$0F,$03,$14,$0F,$12,$2C,$20,$27,$52,$0F,$02,$0F,$14,$27
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $54,$08,$05,$20,$09,$0D,$01,$07,$05,$13,$20,$08,$05,$12,$05,$20,$08,$01,$16,$05,$20,$02,$05,$05,$0E,$20,$10,$09,$18,$05,$0C,$0C,$05,$04,$20,$02,$19,$20,$0D,$19
!byte $47,$12,$01,$0E,$04,$13,$0F,$0E,$20,$28,$17,$09,$14,$08,$20,$13,$15,$10,$10,$0F,$12,$14,$20,$06,$12,$0F,$0D,$20,$0D,$05,$29,$20,$15,$13,$09,$0E,$07,$20,$0D,$19
!byte $0E,$05,$17,$20,$03,$12,$0F,$13,$13,$2D,$04,$05,$16,$20,$13,$03,$12,$05,$05,$0E,$20,$05,$04,$09,$14,$0F,$12,$20,$27,$43,$08,$09,$0C,$0C,$45,$44,$27,$2E,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $47,$12,$05,$05,$14,$09,$0E,$07,$13,$20,$14,$0F,$3A,$20,$20,$4D,$0F,$0C,$0F,$03,$08,$2C,$20,$57,$01,$12,$0C,$0F,$03,$0B,$2C,$20,$12,$05,$04,$02,$01,$03,$0B,$2C
!byte $54,$2E,$4D,$2E,$52,$2C,$20,$20,$4F,$04,$09,$05,$20,$20,$01,$0E,$04,$20,$01,$0C,$0C,$20,$20,$20,$0F,$14,$08,$05,$12,$20,$0D,$05,$0D,$02,$05,$12,$13,$20,$0F,$06
!byte $02,$0F,$14,$08,$20,$41,$12,$0B,$01,$0E,$09,$18,$20,$4C,$01,$02,$13,$20,$01,$0E,$04,$20,$43,$0F,$13,$09,$0E,$05,$2E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $54,$08,$01,$0E,$0B,$13,$20,$14,$0F,$20,$01,$0C,$0C,$20,$20,$14,$08,$0F,$13,$05,$20,$0F,$0E,$20,$43,$53,$44,$02,$20,$01,$0E,$04,$20,$54,$17,$09,$14,$14,$05,$12
!byte $17,$08,$0F,$20,$08,$01,$16,$05,$20,$20,$08,$05,$0C,$10,$05,$04,$20,$01,$0E,$04,$20,$20,$13,$15,$10,$10,$0F,$12,$14,$05,$04,$20,$20,$0D,$05,$20,$0F,$16,$05,$12
!byte $14,$08,$05,$20,$19,$05,$01,$12,$13,$20,$17,$09,$14,$08,$20,$01,$04,$16,$09,$03,$05,$20,$01,$0E,$04,$20,$03,$0F,$0D,$0D,$05,$0E,$14,$13,$21,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $50,$0C,$05,$01,$13,$05,$20,$16,$09,$13,$09,$14,$2E,$2E,$2E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$17,$17,$17,$2E,$01,$12,$0B,$01,$0E,$09,$18,$0C,$01,$02,$13,$2E,$03,$0F,$0D,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$17,$17,$17,$2E,$03,$0F,$13,$09,$0E,$05,$2E,$0F,$12,$07,$2E,$15,$0B,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $01,$4E,$04,$19,$2F,$41,$4C,$2F,$43,$0F,$13,$09,$0E,$05,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$4A,$15,$0E,$05,$20,$32,$30,$31,$39


;Screen data for Vortex screen 1
scrramvortex1
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$E2,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$6C,$E4,$E4,$E4,$7B,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E8,$E8,$E8,$E8,$E8,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5B,$DD,$5B,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5E,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$62,$62,$62,$20,$20,$62,$62,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

colramvortex1
!byte $06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06
!byte $0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B
!byte $0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$00,$00,$00,$03,$00,$00,$00,$00,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B
!byte $0B,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$06,$06,$06,$06,$06,$0E,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$06,$06,$06,$06,$06,$06,$06,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$06,$06,$06,$06,$06,$06,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$06,$01,$06,$01,$06,$06,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$06,$0E,$03,$0E,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$06,$01,$06,$06,$06,$06,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$06,$06,$06,$06,$06,$06,$06,$06,$0E,$06,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$06,$06,$06,$06,$06,$06,$06,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$06,$06,$06,$06,$06,$06,$06,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B

!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$06,$06,$06,$06,$06,$06,$06,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$06,$06,$06,$06,$06,$06,$06,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$06,$00,$00,$06,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$06,$0E,$01,$0E,$0E,$0E,$0E,$01,$0E,$06,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$0E,$01,$01,$01,$01,$0E,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$0E,$0E,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$00,$00,$00,$00,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$03,$03,$03,$03,$03,$03,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B
!byte $0B,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B
!byte $0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B
!byte $0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B
!byte $06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06


;Screen data for Vortex screen 2
scrramvortex2
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$E2,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$7E,$A0,$7C,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$6C,$E4,$E4,$E4,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E8,$E8,$E8,$E8,$E8,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5B,$DD,$5B,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5E,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$62,$62,$62,$A0,$62,$62,$62,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

colramvortex2
!byte $06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06
!byte $0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B
!byte $04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04
!byte $04,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$01,$01,$01,$01,$01,$01,$01,$03,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$0E,$0E,$0E,$0E,$0E,$06,$06,$06,$06,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$06,$0B,$0B,$0B,$06,$06,$01,$06,$01,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$00,$00,$06,$06,$01,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$06,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$06,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$06,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$06,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$06,$06,$06,$06,$06,$00,$06,$0E,$01,$0E,$06,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$00,$00,$00,$00,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$01,$01,$01,$01,$01,$01,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$06,$04
!byte $04,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$04
!byte $04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04
!byte $0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B
!byte $06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0E,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$03,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06


;Screen data for Vortex screen 3
scrramvortex3
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$E2,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$7E,$A0,$7C,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E4,$E4,$E4,$7B,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E8,$E8,$E8,$E8,$E8,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5B,$DD,$5B,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5E,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$62,$62,$62,$62,$62,$62,$62,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

colramvortex3
!byte $06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06
!byte $04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04
!byte $0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E
!byte $0E,$04,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$00,$00,$00,$00,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$0B,$0B,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$0B,$04,$04,$04,$04,$0B,$06,$00,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$04,$0B,$0B,$0B,$0B,$0B,$03,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$00,$00,$06,$06,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$00,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$00,$06,$06,$01,$06,$01,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$04,$0B,$0B,$06,$06,$01,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$0B,$04,$04,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$0B,$06,$00,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$0E,$01,$0E,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$00,$06,$0E,$01,$0E,$06,$00,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$00,$04,$0E
!byte $0E,$04,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$04,$0E
!byte $0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E
!byte $04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04
!byte $06,$04,$0E,$04,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06,$00,$06,$04,$0E,$04,$06


;Screen data for Vortex screen 4
scrramvortex4
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$E2,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$7E,$A0,$7C,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$EC,$6C,$E4,$E4,$E4,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E8,$E8,$E8,$E8,$E8,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5B,$DD,$5B,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5E,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$62,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

colramvortex4
!byte $06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06
!byte $0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E
!byte $03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03
!byte $03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$04,$04,$04,$04,$04,$04,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$00,$00,$00,$00,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$04,$04,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$04,$0E,$0E,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$04,$0E,$04,$04,$04,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$03,$04,$06,$00,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$06,$06,$06,$06,$00,$00,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$06,$06,$06,$06,$06,$06,$06,$00,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$06,$06,$06,$06,$06,$06,$06,$00,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$06,$06,$01,$06,$01,$06,$06,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$06,$06,$06,$06,$06,$06,$06,$04,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$06,$06,$01,$06,$06,$06,$06,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$06,$06,$06,$06,$06,$06,$06,$04,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$06,$06,$06,$06,$06,$06,$06,$00,$00,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$0B,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$04,$04,$04,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$00,$0E,$03
!byte $03,$0E,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$0B,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$0E,$03
!byte $03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03
!byte $0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E
!byte $06,$0E,$03,$0E,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06,$00,$06,$0E,$03,$0E,$06


;Screen data for Vortex screen 5
scrramvortex5
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E2,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$7E,$A0,$7C,$FB,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E4,$E4,$E4,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$6C,$E8,$E8,$E8,$E8,$E8,$7B,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5B,$DD,$5B,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5E,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$A0,$DD,$A0,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$E5,$5F,$DD,$E9,$EA,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E1,$C0,$C0,$C0,$C0,$C0,$61,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$62,$62,$62,$62,$62,$62,$62,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0

colramvortex5
!byte $06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06
!byte $0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E
!byte $01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01
!byte $01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$04,$04,$04,$04,$04,$04,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$03,$04,$04,$04,$04,$04,$04,$04,$04,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$06,$06,$06,$06,$00,$00,$00,$00,$00,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$0E,$0E,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$03,$03,$03,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$01,$06,$01,$06,$06,$0E,$0E,$0E,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$06,$00,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$01,$06,$06,$06,$06,$00,$00,$00,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$00,$00,$00,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$00,$00,$00,$00,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$06,$00,$00,$06,$0E,$03,$0E,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$0E,$0E,$0E,$0E,$03,$0E,$06,$00,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$06,$06,$06,$06,$06,$06,$03,$03,$03,$03,$0E,$06,$00,$06,$04,$0E,$04,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$00,$06,$04,$0E,$04,$06,$06,$06,$0E,$0E,$0E,$0E,$06,$00,$06,$04,$0E,$04,$06,$00,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$06,$00,$00,$00,$00,$00,$00,$06,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$04,$04,$04,$04,$04,$04,$04,$04,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$00,$0E,$01
!byte $01,$0E,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$04,$04,$04,$04,$04,$04,$04,$04,$06,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$0E,$01
!byte $01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$06,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01
!byte $0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E
!byte $06,$0E,$01,$0E,$06,$00,$06,$0B,$0B,$06,$06,$00,$06,$0B,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$04,$0B,$06,$00,$06,$06,$0B,$0B,$06,$00,$06,$0E,$01,$0E,$06


; Byte store buffer for screen and colour RAM data!
; Blank at the starts, but will be populated when each screen is
; copied here and then used by the print screen subroutine!

screen_store
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

colour_store
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00


; Note page colour wash tables called from irq code

wash_col_off
		!byte $00,$01,$02,$01,$00,$01,$02,$01
		!byte $08,$07,$06,$05,$04,$03,$02,$04
		!byte $06,$08,$0a,$0c,$0e,$00,$0f,$0e
		!byte $0d,$0c,$0b,$0a,$09,$08,$07,$06
		!byte $0c,$0c,$0b,$0a,$0b,$0c,$0c,$0e		
		
wash_pulse
		!byte $06,$06,$04,$0e,$0e,$03,$01,$01
		!byte $03,$01,$01,$03,$0e,$0e,$04,$06			
		
; That's all folks!
